@@ -23,7 +23,6 @@ def load_test_data(data_filename):
     if isinstance(data_filename, str):
         with open(data_filename, 'rb') as f:
             data_set = tablib.Dataset().load(f.read())
-            print(data_set)
             return data_set.dict
     else:
         return []
@@ -156,8 +155,7 @@ class UnitCase(UnitHttpFrame, metaclass=CaseMetaclass):
                 pass
 
         # Request start
-        if hasattr(http, method):
+        if url and hasattr(http, method):
             do = getattr(http, method)
             self.response.set(do(url=url, **{body_type: body}))
             self.logger.debug(repr(self.response))
-
